@@ -4,9 +4,7 @@
  * GChemPaint library
  * document.cc 
  *
- * Copyright (C) 2001-2005
- *
- * Developed by Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2001-2005 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -185,7 +183,7 @@ bool gcpDocument::ImportOB(OBMol& Mol)
 	OBBond *bond;
 	vector<OBEdgeBase*>::iterator j;
 	bond = Mol.BeginBond(j);
-	double l = floor(DefaultBondLength / bond->GetLength());
+	double l = (bond)? floor(DefaultBondLength / bond->GetLength()): 1.;
 	if (l == 0) l = 1;
 	m_title = g_strdup(Mol.GetTitle());
 	OBAtom *atom;
@@ -286,6 +284,9 @@ void gcpDocument::ExportOB()
 	BuildAtomTable(AtomTable, this, index);
 	Mol.ReserveAtoms(AtomTable.size());
 	Mol.SetTitle((char*)GetTitle());
+#ifdef HAS_OPENBABEL_2
+	Mol.SetDimension (2);
+#endif
 	for (i = AtomTable.begin(); i != AtomTable.end(); i++)
 	{
 		pgAtom = (gcpAtom*)GetDescendant((*i).first.data());
@@ -710,26 +711,24 @@ xmlDocPtr gcpDocument::BuildXMLTree()
 
 void gcpDocument::Update()
 {
-	std::list<Object*>::iterator i;
+	std::set<Object*>::iterator i,  end = m_DirtyObjects.end ();
 	TypeId Id;
-	for (i = m_DirtyObjects.begin(); i != m_DirtyObjects.end(); i++)
-	{
-		Id = (*i)->GetType();
-		switch (Id)
-		{
-			case BondType:
-				m_pView->Update((gcpBond*)(*i));
-				break;
+	for (i = m_DirtyObjects.begin(); i != end; i++) {
+		Id = (*i)->GetType ();
+		switch (Id) {
+		case BondType:
+			m_pView->Update ((gcpBond*)(*i));
+			break;
 		}
 	}
-	m_DirtyObjects.clear();
+	m_DirtyObjects.clear ();
 }
 	
 void gcpDocument::RemoveAtom(gcpAtom* pAtom)
 {
 	std::map<Atom*, Bond*>::iterator i;
 	gcpBond* pBond;
-	while (pBond = (gcpBond*)pAtom->GetFirstBond(i))
+	while ((pBond = (gcpBond*)pAtom->GetFirstBond(i)))
 	{
 		if (!m_bUndoRedo) m_pCurOp->AddObject(pBond);
 		RemoveBond(pBond);
@@ -745,7 +744,7 @@ void gcpDocument::RemoveFragment(gcpFragment* pFragment)
 	std::map<Atom*, Bond*>::iterator i;
 	gcpAtom* pAtom = pFragment->GetAtom();
 	gcpBond* pBond;
-	while (pBond = (gcpBond*)pAtom->GetFirstBond(i))
+	while ((pBond = (gcpBond*)pAtom->GetFirstBond(i)))
 	{
 		if (!m_bUndoRedo) m_pCurOp->AddObject(pBond);
 		RemoveBond(pBond);
@@ -825,6 +824,7 @@ void gcpDocument::RemoveBond (gcpBond* pBond)
 			m_pView->Update (pAtom1);
 		Parent->Lock (false);
 	}
+	m_DirtyObjects.erase (pBond);
 	delete pBond;
 }
 	
