@@ -4,9 +4,7 @@
  * GChemPaint selection plugin
  * erasertool.cc
  *
- * Copyright (C) 2001-2005
- *
- * Developed by Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2001-2005 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -149,18 +147,17 @@ void gcpEraserTool::OnDrag()
 	}
 }
 
-void gcpEraserTool::OnRelease()
+void gcpEraserTool::OnRelease ()
 {
 	char *id = NULL;
-	if ((!m_pObject) || (!m_bChanged))
-	{
+	if ((!m_pObject) || (!m_bChanged)) {
 		m_pItem = NULL;
 		return;
 	}
-	gcpDocument* pDoc = m_pView->GetDoc();
+	gcpDocument* pDoc = m_pView->GetDoc ();
 	gcpOperation *pOp;
 	Object *pObj = m_pObject->GetGroup (), *Parent;
-	if (pObj && pObj->GetType () != MoleculeType) {
+	if (pObj && (pObj->GetType () != MoleculeType || m_pObject->GetType () == OtherType)) {
 		pOp = pDoc->GetNewOperation (GCP_MODIFY_OPERATION);
 		pOp->AddObject (pObj, 0);
 		id = g_strdup (pObj->GetId ());
@@ -168,22 +165,21 @@ void gcpEraserTool::OnRelease()
 		pOp = pDoc->GetNewOperation (GCP_DELETE_OPERATION);
 		pOp->AddObject (m_pObject);
 	}
-	if (m_pObject->GetType() == AtomType)
-	{
-		Object* parent = m_pObject->GetParent();
-		if (parent->GetType() == FragmentType)	m_pObject = parent;
+	if (m_pObject->GetType () == AtomType) {
+		Object* parent = m_pObject->GetParent ();
+		if (parent->GetType () == FragmentType)
+			m_pObject = parent;
 	}
-//	m_pObject->EmitSignal (OnDeleteSignal); /* This might be not useful */
 	Parent = m_pObject->GetParent ();
 // A molecule might disappear, so get its parent
 	if (Parent->GetType () == MoleculeType)
 		Parent = Parent->GetParent ();
 	m_pItem = NULL;
 	if (m_pData->Items[m_pObject] == NULL) {
-		m_pData->Items.erase(m_pObject);
+		m_pData->Items.erase (m_pObject);
 		return;
 	}
-	pDoc->Remove(m_pObject);
+	pDoc->Remove (m_pObject);
 	Parent->EmitSignal (OnChangedSignal);
 	if (id) {
 		pObj = pDoc->GetChild (id);
@@ -191,5 +187,5 @@ void gcpEraserTool::OnRelease()
 			pOp->AddObject (pObj, 1);
 		g_free (id);
 	}
-	pDoc->FinishOperation();
+	pDoc->FinishOperation ();
 }
