@@ -4,9 +4,7 @@
  * GChemPaint selection plugin
  * selectiontool.cc
  *
- * Copyright (C) 2001-2004
- *
- * Developed by Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2001-2004 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -35,19 +33,19 @@
 #include <math.h>
 #include <stdexcept>
 
-static bool on_flip(GtkWidget *btn, gcpApplication* App)
+static void on_flip(GtkWidget *btn, gcpApplication* App)
 {
 	gcpSelectionTool *tool = (gcpSelectionTool*) App->GetTool ("Select");
 	tool->OnFlip (strcmp (gtk_widget_get_name (btn), "VertFlip"));
 }
 
-static bool on_rotate(GtkWidget *btn, gcpApplication* App)
+static void on_rotate(GtkWidget *btn, gcpApplication* App)
 {
 	gcpSelectionTool *tool = (gcpSelectionTool*) App->GetTool ("Select");
 	tool->Rotate (gtk_toggle_tool_button_get_active (GTK_TOGGLE_TOOL_BUTTON (btn)));
 }
 
-static bool on_merge(GtkWidget *btn, gcpApplication* App)
+static void on_merge(GtkWidget *btn, gcpApplication* App)
 {
 	gcpSelectionTool *tool = (gcpSelectionTool*) App->GetTool ("Select");
 	tool->Merge ();
@@ -362,7 +360,7 @@ static void on_group (gcpSelectionTool* tool)
 void gcpSelectionTool::Group ()
 {
 	gcpDocument *pDoc = m_pView->GetDoc ();
-	gcpGroupDlg *dlg = new gcpGroupDlg (pDoc, NULL);
+	new gcpGroupDlg (pDoc, NULL);
 }
 
 void gcpSelectionTool::CreateGroup ()
@@ -397,7 +395,6 @@ void gcpSelectionTool::CreateGroup ()
 bool gcpSelectionTool::OnRightButtonClicked (GtkUIManager *UIManager)
 {
 	// first destroy the GtkUIManager
-	GtkWidget *w;
 	if (m_pData->SelectedObjects.size () > 1) {
 		GtkActionGroup *group = gtk_action_group_new ("selection");
 		GtkAction *action = gtk_action_new ("group", _("Group and/or align objects"), NULL, NULL);
